@@ -1,20 +1,19 @@
-import tempfile
 import os
 import pathlib
 import random
+import tempfile
 
 import pytest
 
 import networkx as nx
-from networkx.utils.decorators import open_file, not_implemented_for
 from networkx.utils.decorators import (
-    preserve_random_state,
-    py_random_state,
-    np_random_state,
-    random_state,
     argmap,
+    not_implemented_for,
+    np_random_state,
+    open_file,
+    py_random_state,
 )
-from networkx.utils.misc import PythonRandomInterface
+from networkx.utils.misc import PythonRandomInterface, PythonRandomViaNumpyBits
 
 
 def test_not_implemented_decorator():
@@ -205,17 +204,6 @@ class TestOpenFileDecorator:
         self.writer_kwarg(path=None)
 
 
-@preserve_random_state
-def test_preserve_random_state():
-    try:
-        import numpy.random
-
-        r = numpy.random.random()
-    except ImportError:
-        return
-    assert abs(r - 0.61879477158568) < 1e-16
-
-
 class TestRandomState:
     @classmethod
     def setup_class(cls):
@@ -224,19 +212,19 @@ class TestRandomState:
 
     @np_random_state(1)
     def instantiate_np_random_state(self, random_state):
-        assert isinstance(random_state, np.random.RandomState)
-        return random_state.random_sample()
+        allowed = (np.random.RandomState, np.random.Generator)
+        assert isinstance(random_state, allowed)
+        return random_state.random()
 
     @py_random_state(1)
     def instantiate_py_random_state(self, random_state):
-        assert isinstance(random_state, random.Random) or isinstance(
-            random_state, PythonRandomInterface
-        )
+        allowed = (random.Random, PythonRandomInterface, PythonRandomViaNumpyBits)
+        assert isinstance(random_state, allowed)
         return random_state.random()
 
     def test_random_state_None(self):
         np.random.seed(42)
-        rv = np.random.random_sample()
+        rv = np.random.random()
         np.random.seed(42)
         assert rv == self.instantiate_np_random_state(None)
 
@@ -247,7 +235,7 @@ class TestRandomState:
 
     def test_random_state_np_random(self):
         np.random.seed(42)
-        rv = np.random.random_sample()
+        rv = np.random.random()
         np.random.seed(42)
         assert rv == self.instantiate_np_random_state(np.random)
         np.random.seed(42)
@@ -255,7 +243,7 @@ class TestRandomState:
 
     def test_random_state_int(self):
         np.random.seed(42)
-        np_rv = np.random.random_sample()
+        np_rv = np.random.random()
         random.seed(42)
         py_rv = random.random()
 
@@ -263,39 +251,56 @@ class TestRandomState:
         seed = 1
         rval = self.instantiate_np_random_state(seed)
         rval_expected = np.random.RandomState(seed).rand()
-        assert rval, rval_expected
+        assert rval == rval_expected
         # test that global seed wasn't changed in function
-        assert np_rv == np.random.random_sample()
+        assert np_rv == np.random.random()
 
         random.seed(42)
         rval = self.instantiate_py_random_state(seed)
         rval_expected = random.Random(seed).random()
-        assert rval, rval_expected
+        assert rval == rval_expected
         # test that global seed wasn't changed in function
         assert py_rv == random.random()
 
-    def test_random_state_np_random_RandomState(self):
+    def test_random_state_np_random_Generator(self):
         np.random.seed(42)
-        np_rv = np.random.random_sample()
-
+        np_rv = np.random.random()
         np.random.seed(42)
         seed = 1
-        rng = np.random.RandomState(seed)
-        rval = self.instantiate_np_random_state(seed)
-        rval_expected = np.random.RandomState(seed).rand()
-        assert rval, rval_expected
 
-        rval = self.instantiate_py_random_state(seed)
-        rval_expected = np.random.RandomState(seed).rand()
-        assert rval, rval_expected
+        rng = np.random.default_rng(seed)
+        rval = self.instantiate_np_random_state(rng)
+        rval_expected = np.random.default_rng(seed).random()
+        assert rval == rval_expected
+
+        rval = self.instantiate_py_random_state(rng)
+        rval_expected = np.random.default_rng(seed).random(size=2)[1]
+        assert rval == rval_expected
         # test that global seed wasn't changed in function
-        assert np_rv == np.random.random_sample()
+        assert np_rv == np.random.random()
+
+    def test_random_state_np_random_RandomState(self):
+        np.random.seed(42)
+        np_rv = np.random.random()
+        np.random.seed(42)
+        seed = 1
+
+        rng = np.random.RandomState(seed)
+        rval = self.instantiate_np_random_state(rng)
+        rval_expected = np.random.RandomState(seed).random()
+        assert rval == rval_expected
+
+        rval = self.instantiate_py_random_state(rng)
+        rval_expected = np.random.RandomState(seed).random(size=2)[1]
+        assert rval == rval_expected
+        # test that global seed wasn't changed in function
+        assert np_rv == np.random.random()
 
     def test_random_state_py_random(self):
         seed = 1
         rng = random.Random(seed)
         rv = self.instantiate_py_random_state(rng)
-        assert rv, random.Random(seed).random()
+        assert rv == random.Random(seed).random()
 
         pytest.raises(ValueError, self.instantiate_np_random_state, rng)
 
